#################
Aldryn Categories
#################

|pypi_version| |build_status| |coverage_status| |codeclimate|

Aldryn Categories is a simple, Aldryn-compatible project that provides
hierarchical *categories* as an independent model in your project. Categories
are similar to *tags*, but are structured into a taxonomy. The project is
suitable for I18N projects as Categories are fully translatable.

Please see the official `Aldryn Categories documentation <http://aldryn-categories.readthedocs.org>`_,
which includes information on installation.

Developers should also note that the project maintains
`UML diagrams <https://github.com/aldryn/aldryn-categories/blob/master/diagrams/aldryn_categories.pdf>`_
for this project.


************
Contributing
************

Aldryn Categories is a an open-source project. We'll be delighted to receive your
feedback in the form of issues and pull requests. Before submitting your pull
request, please review our `guidelines for Aldryn addons <http://docs.aldryn.com/en/latest/reference/addons/index.html>`_.


************
Requirements
************

1. Python v2.6+
2. Django v1.6.x + South v1.0.2+ (see note below) or Django v1.7+
3. django-treebeard v2.0+
4. django-parler v1.2.1+


.. |pypi_version| image:: http://img.shields.io/pypi/v/aldryn-categories.svg
   :target: https://pypi.python.org/pypi/aldryn-categories
   :alt: PyPI Version
.. |build_status| image:: https://travis-ci.org/aldryn/aldryn-categories.svg?branch=master
   :target: https://travis-ci.org/aldryn/aldryn-categories/
   :alt: Build Status
.. |coverage_status| image:: http://img.shields.io/coveralls/aldryn/aldryn-categories/master.svg
   :target: https://coveralls.io/r/aldryn/aldryn-categories?branch=master
   :alt: Coverage Status
.. |codeclimate| image:: https://codeclimate.com/github/aldryn/aldryn-categories/badges/gpa.svg
   :target: https://codeclimate.com/github/aldryn/aldryn-categories
   :alt: Code Climate
